@@ -1,7 +1,24 @@
 var __defProp = Object.defineProperty;
+var __defProps = Object.defineProperties;
 var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
+var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
 var __getOwnPropNames = Object.getOwnPropertyNames;
+var __getOwnPropSymbols = Object.getOwnPropertySymbols;
 var __hasOwnProp = Object.prototype.hasOwnProperty;
+var __propIsEnum = Object.prototype.propertyIsEnumerable;
+var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
+var __spreadValues = (a, b) => {
+  for (var prop in b || (b = {}))
+    if (__hasOwnProp.call(b, prop))
+      __defNormalProp(a, prop, b[prop]);
+  if (__getOwnPropSymbols)
+    for (var prop of __getOwnPropSymbols(b)) {
+      if (__propIsEnum.call(b, prop))
+        __defNormalProp(a, prop, b[prop]);
+    }
+  return a;
+};
+var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
 var __export = (target, all) => {
   for (var name in all)
     __defProp(target, name, { get: all[name], enumerable: true });
@@ -45,14 +62,18 @@ var documentClient = new import_aws_sdk.DynamoDB.DocumentClient({ apiVersion: "2
 var s3 = new import_aws_sdk.S3({ apiVersion: "2006-03-01" });
 async function handler(event) {
   var _a;
+  console.log("Event: %j", event);
+  const response = {
+    statusCode: 201,
+    body: "",
+    headers: process.env.CORS_ALLOW_ORIGINS ? { "Access-Control-Allow-Origin": process.env.CORS_ALLOW_ORIGINS } : void 0
+  };
   try {
-    console.log("Event: %j", event);
     const body = JSON.parse(event.body ?? "{}");
     if (!body.url) {
-      return {
-        statusCode: 400,
-        body: ""
-      };
+      return __spreadProps(__spreadValues({}, response), {
+        statusCode: 400
+      });
     }
     const update = await documentClient.update({
       TableName: getEnv("TABLE_NAME"),
@@ -75,19 +96,17 @@ async function handler(event) {
       ACL: "public-read"
     }).promise();
     console.log("Put object: %j", putObject);
-    return {
-      statusCode: 201,
+    return __spreadProps(__spreadValues({}, response), {
       body: JSON.stringify({
         url: body.url,
         shortUrl: `https://${getEnv("DOMAIN_NAME")}/${key}`
       })
-    };
+    });
   } catch (err) {
     console.log(err);
-    return {
-      statusCode: 500,
-      body: ""
-    };
+    return __spreadProps(__spreadValues({}, response), {
+      statusCode: 500
+    });
   }
 }
 // Annotate the CommonJS export names for ESM import in node:
